var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
export var backgroundColor = '#393941';
export function getPositionOffset(placing, rect, offset, breached, containerRect) {
    var heightOffset = getHeightOffset(rect, containerRect);
    switch (placing) {
        case 'right':
            return {
                top: rect.top + rect.height / 2 - heightOffset,
                transform: 'translate3d(0, -50%, 1px)',
                left: rect.left + rect.width + offset,
            };
        case 'left':
            return {
                top: rect.top + rect.height / 2 - heightOffset,
                transform: 'translate3d(-100%, -50%, 1px)',
                left: rect.left - offset,
            };
        case 'top':
            if (breached) {
                return {
                    top: rect.top - offset,
                    transform: 'translate3d(0, -100%, 1px)',
                };
            }
            return {
                top: rect.top - offset,
                transform: 'translate3d(-50%, -100%, 1px)',
                left: rect.left + rect.width / 2,
            };
        default:
            if (breached) {
                return {
                    top: rect.top + rect.height + offset,
                    transform: 'translate(0, 0, 1px)',
                };
            }
            return {
                top: rect.top + rect.height + offset,
                left: rect.left + rect.width / 2,
                transform: 'translate3d(-50%, 0, 1px)',
            };
    }
}
export function getRect(element) {
    if (element === null) {
        return document.body.getBoundingClientRect();
    }
    return element.getBoundingClientRect();
}
export function getAutoPlacing(rect, placing, width) {
    var bodyClientRect = document.body.getBoundingClientRect();
    if (bodyClientRect.width - rect.right < width / 2 || rect.left < width / 2) {
        var rightSide = bodyClientRect.width - rect.right - width / 2;
        var leftSide = rect.left - width / 2;
        return rightSide > leftSide ? 'right' : 'left';
    }
    return placing;
}
export function getFlexDirection(placing) {
    switch (placing) {
        case 'bottom':
            return { flexDirection: 'column' };
        case 'top':
            return { flexDirection: 'column-reverse' };
        case 'right':
            return { flexDirection: 'row' };
        default:
            return { flexDirection: 'row-reverse' };
    }
}
export function getArrow(placing, rect, breached, containerRect) {
    var oppositeDirectionValue = '7px solid transparent';
    var currentDirectionValue = "12px solid " + backgroundColor;
    var currentDirectionMargin = '-2px';
    var marginRight = "calc(100% - " + (2 * rect.left + rect.width) + "px)";
    switch (placing) {
        case 'top':
            var resultTop = {
                borderLeft: oppositeDirectionValue,
                borderRight: oppositeDirectionValue,
                borderTop: currentDirectionValue,
                marginTop: currentDirectionMargin,
            };
            if (breached) {
                return __assign(__assign({}, resultTop), { marginRight: marginRight });
            }
            return resultTop;
        case 'right':
            var heightOffsetRight = getHeightOffset(rect, containerRect);
            return {
                borderTop: oppositeDirectionValue,
                borderBottom: oppositeDirectionValue,
                borderRight: currentDirectionValue,
                marginRight: currentDirectionMargin,
                marginTop: heightOffsetRight * 2,
            };
        case 'bottom':
            var resultBottom = {
                borderRight: oppositeDirectionValue,
                borderLeft: oppositeDirectionValue,
                borderBottom: currentDirectionValue,
                marginBottom: currentDirectionMargin,
            };
            if (breached) {
                return __assign(__assign({}, resultBottom), { marginRight: marginRight });
            }
            return resultBottom;
        default:
            var heightOffsetLeft = getHeightOffset(rect, containerRect);
            return {
                borderTop: oppositeDirectionValue,
                borderBottom: oppositeDirectionValue,
                borderLeft: currentDirectionValue,
                marginLeft: currentDirectionMargin,
                marginTop: heightOffsetLeft * 2,
            };
    }
}
export var getHeightOffset = function (rect, containerRect) {
    if (containerRect) {
        var bodyClientRect = document.body.getBoundingClientRect();
        // container is cut off at the bottom
        if (bodyClientRect.bottom < containerRect.bottom) {
            return containerRect.bottom - bodyClientRect.bottom;
        }
        // container is cut off at the top
        if (containerRect.top < 0) {
            return containerRect.top - rect.top;
        }
    }
    return 0;
};
